@@ -2225,8 +2225,9 @@ HTSEXT_API int hts_main2(int argc, char **argv, httrackp *opt) {
       // erase ref files if not interrupted
       DIR *dir;
       struct dirent *entry;
+      for(dir = opendir(fconcat(OPT_GET_BUFF(opt), StringBuff(opt->path_log), CACHE_REFNAME))
         ; dir != NULL && ( entry = readdir(dir) ) != NULL 
-        ;
+        ; )
       {
         if (entry->d_name[0] != '\0' && entry->d_name[0] != '.') {
           char *f = OPT_GET_BUFF(opt);
